@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KTQUEUEMANAGER_H
 #define KTQUEUEMANAGER_H
@@ -298,7 +282,7 @@ public Q_SLOTS:
 
 private:
     void startSafely(bt::TorrentInterface *tc);
-    void stopSafely(bt::TorrentInterface *tc, bt::WaitJob *wjob = 0);
+    void stopSafely(bt::TorrentInterface *tc, bt::WaitJob *wjob = nullptr);
     void checkDiskSpace(QList<bt::TorrentInterface *> &todo);
     void checkMaxSeedTime(QList<bt::TorrentInterface *> &todo);
     void checkMaxRatio(QList<bt::TorrentInterface *> &todo);
